@@ -1,6 +1,6 @@
 ///////////////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2012-2017 DreamWorks Animation LLC
+// Copyright (c) 2012-2018 DreamWorks Animation LLC
 //
 // All rights reserved. This software is distributed under the
 // Mozilla Public License 2.0 ( http://www.mozilla.org/MPL/2.0/ )
@@ -31,10 +31,11 @@
 #ifndef OPENVDB_EXCEPTIONS_HAS_BEEN_INCLUDED
 #define OPENVDB_EXCEPTIONS_HAS_BEEN_INCLUDED
 
-#include <exception>
-#include <string>
-#include <iostream>
 #include <openvdb/version.h>
+#include <exception>
+#include <sstream>
+#include <string>
+
 
 namespace openvdb {
 OPENVDB_USE_VERSION_NAMESPACE
@@ -80,7 +81,6 @@ public: \
 
 
 OPENVDB_EXCEPTION(ArithmeticError);
-OPENVDB_EXCEPTION(IllegalValueException);
 OPENVDB_EXCEPTION(IndexError);
 OPENVDB_EXCEPTION(IoError);
 OPENVDB_EXCEPTION(KeyError);
@@ -91,9 +91,17 @@ OPENVDB_EXCEPTION(RuntimeError);
 OPENVDB_EXCEPTION(TypeError);
 OPENVDB_EXCEPTION(ValueError);
 
-
 #undef OPENVDB_EXCEPTION
 
+
+/// @deprecated Use ValueError instead.
+class OPENVDB_API IllegalValueException: public Exception {
+public:
+    OPENVDB_DEPRECATED IllegalValueException() noexcept: Exception("IllegalValueException") {}
+    OPENVDB_DEPRECATED explicit IllegalValueException(const std::string& msg) noexcept:
+        Exception("IllegalValueException", &msg) {}
+};
+
 } // namespace OPENVDB_VERSION_NAME
 } // namespace openvdb
 
@@ -111,6 +119,6 @@ OPENVDB_EXCEPTION(ValueError);
 
 #endif // OPENVDB_EXCEPTIONS_HAS_BEEN_INCLUDED
 
-// Copyright (c) 2012-2017 DreamWorks Animation LLC
+// Copyright (c) 2012-2018 DreamWorks Animation LLC
 // All rights reserved. This software is distributed under the
 // Mozilla Public License 2.0 ( http://www.mozilla.org/MPL/2.0/ )
